@@ -1,8 +1,10 @@
 # Author: Jason Dsouza
 # Github: http://www.github.com/jasmcaus
 
-from ._version import version as __version__
+from ._version import version as v
 from ._version import author as __author__
+version = v
+__version__ = v
 
 from .preprocess import preprocess_from_dir
 from .preprocess import sep_train
@@ -11,20 +13,25 @@ from .preprocess import reshape
 from .preprocess import normalize
 from .preprocess import _printTotal
 
-# from .io import HDF5Dataset
-# from .io import load_dataset
-
 from .utils import readImg
 from .utils import saveNumpy
 from .utils import train_val_split
 from .utils import get_classes_from_dir
 from .utils import sort_dict
 from .utils import plotAcc
-from .utils import get_opencv_version
-from .utils import url_to_image 
-from .utils import toMatplotlib 
-from .utils import translate
-from .utils import rotate 
-from .utils import rotate_bound 
-from .utils import resize 
-from .utils import canny 
\ No newline at end of file
+
+from .paths import list_media
+from .paths import list_images
+from .paths import list_videos
+from .paths import listdir
+
+from .opencv import get_opencv_version
+from .opencv import to_gray
+from .opencv import to_hsv
+from .opencv import to_lab
+from .opencv import to_rgb
+from .opencv import url_to_image 
+from .opencv import translate
+from .opencv import rotate 
+from .opencv import rotate_bound 
+from .opencv import canny 
\ No newline at end of file
