@@ -8,9 +8,7 @@ sys.path.append('..')
 import os
 import time
 import numpy as np
-from .utils import readImg
-from .utils import saveNumpy
-from .utils import get_classes_from_dir
+from .utils import readImg, saveNumpy, get_classes_from_dir
 from .preprocessing import MeanProcess
 
 def preprocess_from_dir(DIR, 
@@ -23,25 +21,35 @@ def preprocess_from_dir(DIR,
                         isShuffle=True, 
                         save_train=False, 
                         destination_filename=None, 
-                        display_count=True):
+                        verbose=1):
     """
     Reads Images in base directory DIR using 'classes' (computed from sub directories )
-    :param DIR: Directory 
-    :param classes: A list of folder names within 'DIR'
-    :param channels: Number of channels each image will be processed to (default: 1)
+    @param DIR: Directory 
+    @param classes --> A list of folder names within `DIR`
+    @param channels: Number of channels each image will be processed to (default: 1)
     :param train_size: Size of the training set
     :param normalize_train: Whether to normalize each image to between [0,1]
     :param mean_subtraction: Whether mean subtraction should be applied (Tuple)
     :param isShuffle: Shuffle the training set
     :param save_train: If True, saves the training set as a .npy or .npz file based on destination_filename
     :param destination_filename: if save_train is True, the train set will be saved as the filename specified
-    :param display_count: Displays the progress as preprocessing continues
+    :param verbose: Integer either 0 (verbosity off) or 1 (verbosity on). Displays the progress to the terminal as preprocessing continues. Default = 1
     
     :return train: Image Pixel Values with corresponding labels (float32)
-    Saves the above variables as .npy files if save_train = True
+    :return classes: ONLY if `classes=None`
+    Saves the above variables as .npy files if `save_train = True`
     """
-
+    return_classes = False
     train = [] 
+    if verbose in [0,1]:
+        if verbose == 0:
+            display_count = False
+        else:
+            display_count = True
+
+    if classes is None:
+        return_classes = True
+
     if save_train:
         if destination_filename is None:
             raise TypeError('[ERROR] Specify a destination file name')
@@ -52,21 +60,20 @@ def preprocess_from_dir(DIR,
         elif destination_filename is not None:
             destination_filename = None
     
-    elif classes is not None:
-        if type(classes) is not list:
-            raise ValueError('[ERROR] "classes" must be a list')
+    if classes is not None and type(classes) is not list:
+        raise ValueError('[ERROR] "classes" must be a list')
 
-    elif not os.path.exists(DIR):
+    if not os.path.exists(DIR):
         raise ValueError('[ERROR] The specified directory does not exist', DIR)
 
-    elif IMG_SIZE is None:
+    if IMG_SIZE is None:
         raise ValueError('[ERROR] IMG_SIZE must be specified')
 
-    elif type(IMG_SIZE) is not int:
+    if type(IMG_SIZE) is not int:
         raise ValueError('[ERROR] IMG_SIZE must be an integer')
 
     # Loading from Numpy Files
-    elif destination_filename is not None and os.path.exists(destination_filename):
+    if destination_filename is not None and os.path.exists(destination_filename):
         since = time.time()
         print('[INFO] Loading from Numpy Files')
         train = np.load(destination_filename, allow_pickle=True)
@@ -155,7 +162,10 @@ def preprocess_from_dir(DIR,
         print('----------------------------------------------')
         print('[INFO] Preprocessing complete! Took {:.0f}m {:.0f}s'.format(time_elapsed_preprocess // 60, time_elapsed_preprocess % 60))
 
-        return train, classes
+        if return_classes:
+            return train, classes
+        else:
+            return train
 
 def _printTotal(count, category):
     print(f'{count} - {category}')
